BioSimulators-COPASI documentation
=====================================

BioSimulators-COPASI provides a `BioSimulators <https://biosimulators.org>`_-compliant command-line interface to the `COPASI <http://copasi.org>`_ biological simulation tool. A Docker image for this package is also available.

This command-line interface and Docker image enable users to use COPASI to execute `COMBINE/OMEX archives <https://combinearchive.org/>`_ that describe one or more simulation experiments (in `SED-ML format <https://sed-ml.org>`_) of one or more models (in `SBML format <http://sbml.org>`_).

A list of the algorithms and algorithm parameters supported by COPASI is available at `BioSimulators <https://biosimulators.org/simulators/copasi>`_.

A simple web application and web service for using COPASI to execute COMBINE/OMEX archives is also available at `runBioSimulations <https://run.biosimulations.org>`_.

Contents
--------

.. toctree::
   :maxdepth: 2

   installation.rst
   tutorial.rst
   API documentation <source/biosimulators_copasi.rst>
   about.rst
   genindex.rst
